<?php

/**
 * @file
 * select_with_style.views.inc
 *
 * Alterations to Views filter handlers.
 */

/**
 * Implements hook_views_data_alter().
 *
 * Temporarily swap out the taxonomy term filter handlers used in Views.
 *
 * This gets called when:
 * o the widget type is changed on the Manage Fields tab of the content type
 * o a View is saved
 * o the caches get cleared
 *
 * We could implement this in hook_field_views_data_alter().
 * However all hook_field_views_data_alter() implementations are called prior
 * to any hook_views_data_alter() implementations, which means that we cannot
 * place ourselves last via the module weight when competing with other
 * modules implementing that hook.
 */
function select_with_style_views_data_alter(&$data) {
  if (!variable_get('select_with_style_use_in_views', TRUE)) {
    return;
  }
  foreach ($data as $table_name => $table_data) {
    foreach ($table_data as $field_name => $field_data) {
      if (isset($field_data['filter']['handler'])) {
        // If the View has a taxonomy term filter then swap it out for ours.
        $handler = &$data[$table_name][$field_name]['filter']['handler'];
        // is_a() used this way requires PHP 5.3.9. Hence the suppression of
        // error and the poor-man's textual check for suspected subclasses.
        if (@is_a($handler, 'views_handler_filter_term_node_tid', TRUE) || strpos($handler, 'handler_filter_term_node_tid')) {
          $handler = 'select_with_style_handler_filter_term_node_tid';
        }
      }
    }
  }
}
